@@ -33,6 +33,16 @@ from trading_backend.exchanges.ftx import (
     FTX
 )
 
+from trading_backend.exchanges import bybit
+from trading_backend.exchanges.bybit import (
+    Bybit
+)
+
+from trading_backend.exchanges import ascendex
+from trading_backend.exchanges.ascendex import (
+    Ascendex
+)
+
 from trading_backend.exchanges import gateio
 from trading_backend.exchanges.gateio import (
     GateIO
@@ -43,11 +53,19 @@ from trading_backend.exchanges.huobi import (
     Huobi
 )
 
+from trading_backend.exchanges import huobipro
+from trading_backend.exchanges.huobipro import (
+    HuobiPro
+)
+
 __all__ = [
     "Exchange",
     "Binance",
+    "Bybit",
     "OKEx",
     "FTX",
+    "Ascendex",
     "GateIO",
     "Huobi",
+    "HuobiPro",
 ]
